StartSimulationInput

Struct StartSimulationInput 

#[non_exhaustive]
pub struct StartSimulationInput { pub client_token: Option<String>, pub name: Option<String>, pub description: Option<String>, pub role_arn: Option<String>, pub schema_s3_location: Option<S3Location>, pub maximum_duration: Option<String>, pub tags: Option<HashMap<String, String>>, pub snapshot_s3_location: Option<S3Location>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
client_token: Option<String>

A value that you provide to ensure that repeated calls to this API operation using the same parameters complete only once. A ClientToken is also known as an idempotency token. A ClientToken expires after 24 hours.

name: Option<String>

The name of the simulation.

description: Option<String>

The description of the simulation.

role_arn: Option<String>

The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that the simulation assumes to perform actions. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference. For more information about IAM roles, see IAM roles in the Identity and Access Management User Guide.

schema_s3_location: Option<S3Location>

The location of the simulation schema in Amazon Simple Storage Service (Amazon S3). For more information about Amazon S3, see the Amazon Simple Storage Service User Guide .

Provide a SchemaS3Location to start your simulation from a schema.

If you provide a SchemaS3Location then you can't provide a SnapshotS3Location.

maximum_duration: Option<String>

The maximum running time of the simulation, specified as a number of minutes (m or M), hours (h or H), or days (d or D). The simulation stops when it reaches this limit. The maximum value is 14D, or its equivalent in the other units. The default value is 14D. A value equivalent to 0 makes the simulation immediately transition to Stopping as soon as it reaches Started.

tags: Option<HashMap<String, String>>

A list of tags for the simulation. For more information about tags, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference.

snapshot_s3_location: Option<S3Location>

The location of the snapshot .zip file in Amazon Simple Storage Service (Amazon S3). For more information about Amazon S3, see the Amazon Simple Storage Service User Guide .

Provide a SnapshotS3Location to start your simulation from a snapshot.

The Amazon S3 bucket must be in the same Amazon Web Services Region as the simulation.

If you provide a SnapshotS3Location then you can't provide a SchemaS3Location.

Implementations

Source

impl StartSimulationInput

pub fn client_token(&self) -> Option<&str>

A value that you provide to ensure that repeated calls to this API operation using the same parameters complete only once. A ClientToken is also known as an idempotency token. A ClientToken expires after 24 hours.

pub fn name(&self) -> Option<&str>

The name of the simulation.

pub fn description(&self) -> Option<&str>

The description of the simulation.

pub fn role_arn(&self) -> Option<&str>

The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role that the simulation assumes to perform actions. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference. For more information about IAM roles, see IAM roles in the Identity and Access Management User Guide.

pub fn schema_s3_location(&self) -> Option<&S3Location>

The location of the simulation schema in Amazon Simple Storage Service (Amazon S3). For more information about Amazon S3, see the Amazon Simple Storage Service User Guide .

Provide a SchemaS3Location to start your simulation from a schema.

If you provide a SchemaS3Location then you can't provide a SnapshotS3Location.

pub fn maximum_duration(&self) -> Option<&str>

The maximum running time of the simulation, specified as a number of minutes (m or M), hours (h or H), or days (d or D). The simulation stops when it reaches this limit. The maximum value is 14D, or its equivalent in the other units. The default value is 14D. A value equivalent to 0 makes the simulation immediately transition to Stopping as soon as it reaches Started.

pub fn tags(&self) -> Option<&HashMap<String, String>>

A list of tags for the simulation. For more information about tags, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference.

pub fn snapshot_s3_location(&self) -> Option<&S3Location>

The location of the snapshot .zip file in Amazon Simple Storage Service (Amazon S3). For more information about Amazon S3, see the Amazon Simple Storage Service User Guide .

Provide a SnapshotS3Location to start your simulation from a snapshot.

The Amazon S3 bucket must be in the same Amazon Web Services Region as the simulation.

If you provide a SnapshotS3Location then you can't provide a SchemaS3Location.

Source

impl StartSimulationInput

pub fn builder() -> StartSimulationInputBuilder

Creates a new builder-style object to manufacture StartSimulationInput.