#[non_exhaustive]pub struct SimulationAppPortMapping {
pub declared: Option<i32>,
pub actual: Option<i32>,
}Expand description
A collection of TCP/UDP ports for a custom or service app.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.declared: Option<i32>The TCP/UDP port number of the app, declared in the simulation schema. SimSpace Weaver maps the Declared port to the Actual port. The source code for the app should bind to the Declared port.
actual: Option<i32>The TCP/UDP port number of the running app. SimSpace Weaver dynamically assigns this port number when the app starts. SimSpace Weaver maps the Declared port to the Actual port. Clients connect to the app using the app's IP address and the Actual port number.
Implementations
Sourceimpl SimulationAppPortMapping
impl SimulationAppPortMapping
Sourceimpl SimulationAppPortMapping
impl SimulationAppPortMapping
Sourcepub fn builder() -> SimulationAppPortMappingBuilder
pub fn builder() -> SimulationAppPortMappingBuilder
Creates a new builder-style object to manufacture SimulationAppPortMapping.