#[non_exhaustive]pub struct SimulationMetadata {
pub name: Option<String>,
pub arn: Option<String>,
pub creation_time: Option<DateTime>,
pub status: Option<SimulationStatus>,
pub target_status: Option<SimulationTargetStatus>,
}Expand description
A collection of data about the simulation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the simulation.
arn: Option<String>The Amazon Resource Name (ARN) of the simulation. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
creation_time: Option<DateTime>The time when the simulation was created, expressed as the number of seconds and milliseconds in UTC since the Unix epoch (0:0:0.000, January 1, 1970).
status: Option<SimulationStatus>The current status of the simulation.
target_status: Option<SimulationTargetStatus>The desired status of the simulation.
Implementations
Sourceimpl SimulationMetadata
impl SimulationMetadata
Sourcepub fn arn(&self) -> Option<&str>
pub fn arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the simulation. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
Sourcepub fn creation_time(&self) -> Option<&DateTime>
pub fn creation_time(&self) -> Option<&DateTime>
The time when the simulation was created, expressed as the number of seconds and milliseconds in UTC since the Unix epoch (0:0:0.000, January 1, 1970).
Sourcepub fn status(&self) -> Option<&SimulationStatus>
pub fn status(&self) -> Option<&SimulationStatus>
The current status of the simulation.
Sourcepub fn target_status(&self) -> Option<&SimulationTargetStatus>
pub fn target_status(&self) -> Option<&SimulationTargetStatus>
The desired status of the simulation.
Sourceimpl SimulationMetadata
impl SimulationMetadata
Sourcepub fn builder() -> SimulationMetadataBuilder
pub fn builder() -> SimulationMetadataBuilder
Creates a new builder-style object to manufacture SimulationMetadata.